==> haskell-hspec-megaparsec-1.1.0-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 1.1.0
id: hspec-megaparsec-1.1.0-Im0IGh0nXGH8GXmeSAGnf2
key: hspec-megaparsec-1.1.0-Im0IGh0nXGH8GXmeSAGnf2
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 5c91bbae669a998a6150e96a26afda46
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-megaparsec-1.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-megaparsec-1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-megaparsec-1.1.0
hs-libraries: HShspec-megaparsec-1.1.0-Im0IGh0nXGH8GXmeSAGnf2
depends:
    base-4.11.1.0 containers-0.5.11.0
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    megaparsec-6.5.0-1gmJqnPWlKT91zM6ODh7K7
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=b75babfddd4aa9a267b9714ea3ac9e19
             megaparsec-6.5.0-1gmJqnPWlKT91zM6ODh7K7=4e7f4599f15caf4b1f34908e730b3db8
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-1.1.0-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-megaparsec
version: 1.1.0
id: hspec-megaparsec-1.1.0-LCrzJMds5MmFTUAPNEDnt2
key: hspec-megaparsec-1.1.0-LCrzJMds5MmFTUAPNEDnt2
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/hspec-megaparsec
synopsis: Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.
category: Testing, Parsing
abi: 2b4c46518759d31f829442d40a25e6f5
exposed: True
exposed-modules:
    Test.Hspec.Megaparsec
import-dirs: /usr/lib/ghc-8.6.1/site-local/hspec-megaparsec-1.1.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/hspec-megaparsec-1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/hspec-megaparsec-1.1.0
hs-libraries: HShspec-megaparsec-1.1.0-LCrzJMds5MmFTUAPNEDnt2
depends:
    base-4.12.0.0 containers-0.6.0.1
    hspec-expectations-0.8.2-EQolLGCe6il5TbRMQrSrzg
    megaparsec-6.5.0-H8uHgj645yksoUPNfpvnU
haddock-interfaces: /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock
haddock-html: /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
